#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-2BbWFaHH5K5BzDFQ89265O
key:                  gitit-0.15.1.2-2BbWFaHH5K5BzDFQ89265O
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  3cff197063f55b160bfce9ea29dbd72a
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-2BbWFaHH5K5BzDFQ89265O
depends:
    HStringTemplate-0.8.8-FGNGRfE1NkQDzCwZhFr96T
    HTTP-4000.5.0-LDby5ZACPybDDeyuZwXSBN
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0 base-4.18.2.1
    base64-bytestring-1.2.1.0-7bYUUcNMltODtdJX73Bu5o
    blaze-html-0.9.2.0-FabkuXZBABUKDnPHGVQGa9 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-49mCyLo7T7y9rzL8DvgmDI
    feed-1.3.2.1-8mVWTfd323BXHgR3Oa9V7 filepath-1.4.300.1
    filestore-0.6.5.1-fUME8ZMDZEJOfe68CR0X3 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-EUMhhEJE3BW2U6rDav5Y3H
    hoauth2-2.14.0-DsfV6sCUfGcAzn9lMlZPxO
    hslogger-1.3.2.0-VyLVL28s6RKTU9G8QctOI
    http-client-tls-0.3.6.4-PDqn3Ot8iJH3sGWMePnKH
    http-conduit-2.3.9.1-4OKabEv3E63AasK3MObPIq
    json-0.11-8lNNdGLbGjvAsWhsz0sm7l mtl-2.3.1
    network-3.1.4.0-D5In1g0c1o5Lno6WiKQzlZ
    network-bsd-2.8.1.0-8BqtmkW5m3iIgud3pVC9kP
    network-uri-2.6.4.2-EPISvuAciHNCNyhUbkgF33
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-4iR91eqe1TJ6Tq9wKtO7GM
    pandoc-types-1.23.1.1-EpiaRPHbze3E9u60a8HftR parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-5RWjRNGMcAI4pn7QxDBoxf
    recaptcha-0.1.0.4-4u4j37pHcSg9ekmdT5rF0a
    safe-0.3.21-2tAFAn43vej8J3ESLti7k9
    skylighting-0.14.4-JVZTaUKEZF6HJOgY4JjVZR
    split-0.2.5-Qi12kQYJr1H6TmSRWYEeS syb-0.7.3-IWvKvWWONKwAx7053zcTAl
    tagsoup-0.14.8-VKPaMjHnlnLdFDJ1dmgRl
    temporary-1.3-8J7tb17AXGL7EVC1xEc9YW text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-CAPpDv1jEgIB3dfbOiYBMv
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-DhWV9fEoepV648QL3EtyBy xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-8EDJmzgpcLz8j2nsgcC68X
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-Kqqh7AHefkh2nRZMKFp9nf
    zlib-0.7.1.0-DirfdD9kavL4Ly7NEYaRSf

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

